@@ -3,34 +3,41 @@ package MooseX::SimpleConfig;
 use Moose::Role;
 with 'MooseX::ConfigFromFile';
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 
 use Config::Any ();
 
 sub get_config_from_file {
     my ($class, $file) = @_;
 
+    my $files_ref = ref $file eq 'ARRAY' ? $file : [$file];
+
     my $can_config_any_args = $class->can('config_any_args');
     my $extra_args = $can_config_any_args ?
         $can_config_any_args->($class, $file) : {};
     ;
     my $raw_cfany = Config::Any->load_files({
-        use_ext => 1,
         %$extra_args,
-        files => [ $file ]
+        use_ext         => 1,
+        files           => $files_ref,
+        flatten_to_hash => 1,
     } );
 
-    die q{Specified configfile '} . $file
-        . q{' does not exist, is empty, or is not readable}
-            unless $raw_cfany->[0]
-                && exists $raw_cfany->[0]->{$file};
+    my %raw_config;
+    foreach my $file_tested ( @{$files_ref} ) {
+        if ( ! exists $raw_cfany->{$file_tested} ) {
+            die qq{Specified configfile '$file_tested' does not exist, } .
+                q{is empty, or is not readable};
+        }
 
-    my $raw_config = $raw_cfany->[0]->{$file};
+        my $cfany_hash = $raw_cfany->{$file_tested};
+        die "configfile must represent a hash structure in file: $file_tested"
+            unless $cfany_hash && ref $cfany_hash && ref $cfany_hash eq 'HASH';
 
-    die "configfile must represent a hash structure"
-        unless $raw_config && ref $raw_config && ref $raw_config eq 'HASH';
+        %raw_config = ( %raw_config, %{$cfany_hash} );
+    }
 
-    $raw_config;
+    \%raw_config;
 }
 
 no Moose::Role; 1;
@@ -116,6 +123,13 @@ provide a default configfile pathname like so:
 
   has +configfile ( default => '/etc/myapp.yaml' );
 
+You can pass an array of filenames if you want, but as usual the array
+has to be wrapped in a sub ref.
+
+  has +configfile ( default => sub { [ '/etc/myapp.yaml', '/etc/myapp_local.yml' ] } );
+
+Config files are trivially merged at the top level, with the right-hand files taking precedence.
+
 =head1 CLASS METHODS
 
 =head2 new_with_config
